%{!?kernel_version: %{expand: %%define kernel_version %(uname -r|sed -e 's/EL.*$/EL/g')}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | sed -e 's/.*EL//g' | sed -e 's/^$/up/g')}}

# On RHEL 4, up type has no tag
%if "%{type}" != "up"
%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}%{type}
%define kernel_devel kernel-%{type}-devel
%else
%define releasetag %{kversionreltag}
%define kernel_dir %{kernel_version}
%define kernel_devel kernel-devel
%endif

# Keep the modKey def identical to that in util.sh-PMWV.*
%define modKey 'PMWV|%{type}|vmsync'
%define vmwDB /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl --os=linux,rhel,4
%define vmwPMWV /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-pmwv.pl --os=linux,rhel,4 --release=%{kernel_dir} --build 1065307 --modKey %{modKey}
%define kmp_version %version

Name:         vmware-tools-vmsync
BuildRequires: %{kernel_devel} gcc
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmsync kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.1.0.1
Release:      1.el4
BuildRoot:    %{_tmppath}/%{name}-%{version}-build
Source1:      vmsync-configModule.tar.gz

Source0:      vmsync.tar

%prep
%setup -n vmsync-only

%build
make clean
make

# NOTE: RHEL 4 has MODVERSIONS enabled but does not generate the module.symvers
#       file we would need in order to properly propagate symbol versions
#       in-between interdependent kernel modules.  See bug 568405 for more info.
if [ "vmsync" = "vsock" -o "vmsync" = "vmhgfs" ]; then
   echo
   echo
   echo "Please ignore the \"VMCI_ ... undefined!\" warnings generated by the build system."
   echo "The vmsync module will load and function properly despite those warnings."
   echo
   echo
fi

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
# The following command copies our newly build kernel module to a known
# location.  Unfortunately sometimes the kmod source build places the kmods
# in inconsistent locations.
cp ../vmsync.o . 2>/dev/null || true
cp driver-%{kernel_version}/vmsync-xxx-%{kernel_version} ./vmsync.o 2>/dev/null || true

# Install kernel module
install -m 644 -D vmsync.o $RPM_BUILD_ROOT/lib/modules/%{kernel_dir}/extra/%{name}/vmsync.ko
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmsync.  The vmsync kernel module provides functions used by VMware Tools to freeze I/O to mounted file systems and flush any in-memory data to disk, used when quiescing virtual machines.

%package common
Summary:      Contains the common files used by all the vmsync kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:9.0.5
Release:      1.el4
Version:      9.0.5

%description common
 This package contains the common system configuration and scripts responsible for loading the vmsync kernel module.  The vmsync kernel module provides functions used by VMware Tools to freeze I/O to mounted file systems and flush any in-memory data to disk, used when quiescing virtual machines.

%package kmp-%{type}
Summary:      The vmsync kernel module built for the %{kernel_version} kernel.
Group:        System/Kernel
Requires:     vmware-tools-vmsync-common
Requires:     vmware-tools-foundation >= 0:9.0.5
Provides:     vmware-tools-vmsync-kmp
Release:      %{kversionreltag}.1.el4


%description kmp-%{type}
 This package contains a pre-compiled vmsync module for use with the %{kernel_version} kernel.   The vmsync kernel module provides functions used by VMware Tools to freeze I/O to mounted file systems and flush any in-memory data to disk, used when quiescing virtual machines.

%pre kmp-%{type}
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmsync stop
   fi

   %{vmwPMWV} --rpmSection=Postun
fi

# Configure
%{vmwPMWV} --rpmSection=Pre

%pre common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmsync ]; then
      /sbin/chkconfig vmsync off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-deconfig.pl --os=linux,rhel,4 --toDeconfigure=vmsync
   /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl --os=linux,rhel,4 --dbDelAnswer VMSYNC_NAME
fi

%post common
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl --os=linux,rhel,4 --dbAddAnswer VMSYNC_NAME,vmsync
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-config.pl --os=linux,rhel,4 --toConfigure=vmsync
if [ -e /etc/init.d/vmsync ]; then
   /sbin/chkconfig vmsync on
fi

%post kmp-%{type}
# Configure
# Invoke the PMWV Post Section
%{vmwPMWV} --rpmSection=Post --baseMod=/lib/modules/%{kernel_dir}/extra/%{name}/vmsync.ko

# If the type matches, start the init script
kmodType=`uname -r | sed -e 's/.*EL//g'`
if [ -z "$kmodType" ]; then
   kmodType=up
fi
if [ "$kmodType" = "%{type}" ]; then
   /etc/init.d/vmsync start
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmsync ]; then
      /sbin/chkconfig vmsync off
   fi
   /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-deconfig.pl --os=linux,rhel,4 --toDeconfigure=vmsync
   /usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl --os=linux,rhel,4 --dbDelAnswer VMSYNC_NAME
fi

%preun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmsync stop
   fi
fi

%postun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   %{vmwPMWV} --rpmSection=Postun
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmsync/vmware-config.pl
/etc/rc.d/init.d/vmsync

%files kmp-%{type}
%defattr(-, root, root, -)
/lib/modules/%{kernel_dir}/extra/%{name}/vmsync.ko


